==> ejc-zdsmaterialb-api-3.0.0-20241114.025133-43-sources.jar: com/ejianc/business/zdsmaterial/erp/vo/BrandRelationQueryVO.java <==
package com.ejianc.business.zdsmaterial.erp.vo;

import com.ejianc.framework.skeleton.template.BaseVO;

/**
 * @author CJ
 * @Description:
 * @date 2024/8/22 19:27
 */
public class BrandRelationQueryVO extends BaseVO {

    private static final long serialVersionUID = 2044252004995296510L;

    private String categorySeq;
    private String materialTypeName;
    private String materialTypeCode;
    private String brandControlFlag;
    private String brandName;
    private String brandSeq;
    private String brandEnabled;
    private String supplierSeq;
    private String supplierCharacter;
    private String supplierName;
    private Long supplierId;
    private Long brandId;
    private Long categoryId;
    private String relationEnabled;
    private Integer categoryTotal;
    private String brandTotal;

    public Long getCategoryId() {
        return categoryId;
    }

    public void setCategoryId(Long categoryId) {
        this.categoryId = categoryId;
    }

    public Integer getCategoryTotal() {
        return categoryTotal;
    }

    public void setCategoryTotal(Integer categoryTotal) {
        this.categoryTotal = categoryTotal;
    }

    public String getBrandTotal() {
        return brandTotal;
    }

    public void setBrandTotal(String brandTotal) {
        this.brandTotal = brandTotal;
    }

    public String getCategorySeq() {
        return categorySeq;
    }

    public void setCategorySeq(String categorySeq) {
        this.categorySeq = categorySeq;
    }

    public String getMaterialTypeName() {
        return materialTypeName;
    }

    public void setMaterialTypeName(String materialTypeName) {
        this.materialTypeName = materialTypeName;
    }

    public String getMaterialTypeCode() {
        return materialTypeCode;
    }

    public void setMaterialTypeCode(String materialTypeCode) {
        this.materialTypeCode = materialTypeCode;
    }

    public String getBrandControlFlag() {
        return brandControlFlag;
    }

    public void setBrandControlFlag(String brandControlFlag) {
        this.brandControlFlag = brandControlFlag;
    }

    public String getBrandName() {
        return brandName;
    }

    public void setBrandName(String brandName) {
        this.brandName = brandName;
    }

    public String getBrandSeq() {
        return brandSeq;
    }

    public void setBrandSeq(String brandSeq) {
        this.brandSeq = brandSeq;
    }

    public String getBrandEnabled() {
        return brandEnabled;
    }

    public void setBrandEnabled(String brandEnabled) {
        this.brandEnabled = brandEnabled;
    }

    public String getSupplierSeq() {
        return supplierSeq;
    }

    public void setSupplierSeq(String supplierSeq) {
        this.supplierSeq = supplierSeq;
    }

    public String getSupplierCharacter() {
        return supplierCharacter;
    }

    public void setSupplierCharacter(String supplierCharacter) {
        this.supplierCharacter = supplierCharacter;
    }

    public String getSupplierName() {
        return supplierName;
    }

    public void setSupplierName(String supplierName) {
        this.supplierName = supplierName;
    }

    public Long getSupplierId() {
        return supplierId;
    }

    public void setSupplierId(Long supplierId) {
        this.supplierId = supplierId;
    }

    public Long getBrandId() {
        return brandId;
    }

    public void setBrandId(Long brandId) {
        this.brandId = brandId;
    }

    public String getRelationEnabled() {
        return relationEnabled;
    }

    public void setRelationEnabled(String relationEnabled) {
        this.relationEnabled = relationEnabled;
    }
}

==> ejc-zdsmaterialb-api-3.0.0-20251031.013959-69-sources.jar: com/ejianc/business/zdsmaterial/erp/vo/BrandRelationQueryVO.java <==
package com.ejianc.business.zdsmaterial.erp.vo;

import com.ejianc.framework.skeleton.template.BaseVO;

/**
 * @author CJ
 * @Description:
 * @date 2024/8/22 19:27
 */
public class BrandRelationQueryVO extends BaseVO {

    private static final long serialVersionUID = 2044252004995296510L;

    private String categorySeq;
    private String materialTypeName;
    private String materialTypeCode;
    private String materialTypePname;
    private String materialTypePEnabled;
    private String brandControlFlag;
    private String brandName;
    private String brandSeq;
    private String brandEnabled;
    private String supplierSeq;
    private String supplierCharacter;
    private String supplierName;
    private Long supplierId;
    private Long brandId;
    private Long categoryId;
    private String relationEnabled;
    private Integer categoryTotal;
    private String brandTotal;

    public String getMaterialTypePname() {
        return materialTypePname;
    }

    public void setMaterialTypePname(String materialTypePname) {
        this.materialTypePname = materialTypePname;
    }

    public String getMaterialTypePEnabled() {
        return materialTypePEnabled;
    }

    public void setMaterialTypePEnabled(String materialTypePEnabled) {
        this.materialTypePEnabled = materialTypePEnabled;
    }

    public Long getCategoryId() {
        return categoryId;
    }

    public void setCategoryId(Long categoryId) {
        this.categoryId = categoryId;
    }

    public Integer getCategoryTotal() {
        return categoryTotal;
    }

    public void setCategoryTotal(Integer categoryTotal) {
        this.categoryTotal = categoryTotal;
    }

    public String getBrandTotal() {
        return brandTotal;
    }

    public void setBrandTotal(String brandTotal) {
        this.brandTotal = brandTotal;
    }

    public String getCategorySeq() {
        return categorySeq;
    }

    public void setCategorySeq(String categorySeq) {
        this.categorySeq = categorySeq;
    }

    public String getMaterialTypeName() {
        return materialTypeName;
    }

    public void setMaterialTypeName(String materialTypeName) {
        this.materialTypeName = materialTypeName;
    }

    public String getMaterialTypeCode() {
        return materialTypeCode;
    }

    public void setMaterialTypeCode(String materialTypeCode) {
        this.materialTypeCode = materialTypeCode;
    }

    public String getBrandControlFlag() {
        return brandControlFlag;
    }

    public void setBrandControlFlag(String brandControlFlag) {
        this.brandControlFlag = brandControlFlag;
    }

    public String getBrandName() {
        return brandName;
    }

    public void setBrandName(String brandName) {
        this.brandName = brandName;
    }

    public String getBrandSeq() {
        return brandSeq;
    }

    public void setBrandSeq(String brandSeq) {
        this.brandSeq = brandSeq;
    }

    public String getBrandEnabled() {
        return brandEnabled;
    }

    public void setBrandEnabled(String brandEnabled) {
        this.brandEnabled = brandEnabled;
    }

    public String getSupplierSeq() {
        return supplierSeq;
    }

    public void setSupplierSeq(String supplierSeq) {
        this.supplierSeq = supplierSeq;
    }

    public String getSupplierCharacter() {
        return supplierCharacter;
    }

    public void setSupplierCharacter(String supplierCharacter) {
        this.supplierCharacter = supplierCharacter;
    }

    public String getSupplierName() {
        return supplierName;
    }

    public void setSupplierName(String supplierName) {
        this.supplierName = supplierName;
    }

    public Long getSupplierId() {
        return supplierId;
    }

    public void setSupplierId(Long supplierId) {
        this.supplierId = supplierId;
    }

    public Long getBrandId() {
        return brandId;
    }

    public void setBrandId(Long brandId) {
        this.brandId = brandId;
    }

    public String getRelationEnabled() {
        return relationEnabled;
    }

    public void setRelationEnabled(String relationEnabled) {
        this.relationEnabled = relationEnabled;
    }
}
